'use strict';
var Generator = require('yeoman-generator');

var _user;
var _password;
var _domain;
var _environment;
var _wolframappid;

var chalk = require('chalk');
var yosay = require('yosay');

module.exports = Generator.extend({

  prompting: function () {
    // Greet the user
    this.log(yosay('Welcome to the terrific ' + chalk.red('PureCloud Chatbot') + ' generator!'));

    var prompts = [
      {
        type: 'input',
        name: 'user',
        message: 'What is your bot username?',
        default: 'bot',
        store: true,
        required: true
      },
      {
        type: 'password',
        name: 'password',
        message: 'What is your bot user password?',
        required: true
      },
      {
        type: 'input',
        name: 'domain',
        message: 'What is your bot\'s email domain?',
        default: 'genesys.com',
        store: true,
        required: true
      },
      {
        type: 'list',
        name: 'environment',
        message: 'What is your PureCloud Environment?',
        choices: [
          'mypurecloud.ie',
          'mypurecloud.com',
          'mypurecloud.jp',
          'mypurecloud.com.au'
        ],
        default: 'mypurecloud.ie',
        store: true,
        required: true
      },
      {
        type: 'input',
        name: 'wolframappid',
        message: 'What is your Wolfram App Id (optional)?',
        store: true,
        required: false
      }
    ];

    return this.prompt(prompts).then(function (props) {
      this.props = props;

      _user = this.props.user;
      _password = this.props.password;
      _domain = this.props.domain;
      _environment = this.props.environment;
      _wolframappid = this.props.wolframappid;
    }.bind(this));
  },

  writing: function () {
    this.fs.copy(
      this.templatePath('PureCloud.ChatBot'),
      this.destinationPath('PureCloud.ChatBot')
    );
    this.fs.copyTpl(
      this.templatePath('PureCloud.ChatBot/App.config'),
      this.destinationPath('PureCloud.ChatBot/App.config'),
      {
        user: _user,
        domain: _domain,
        password: _password,
        environment: _environment,
        wolframappid: _wolframappid
      }
    );
    this.fs.copy(
      this.templatePath('PureCloud.ChatBot.Tests'),
      this.destinationPath('PureCloud.ChatBot.Tests')
    );
    this.fs.copy(
      this.templatePath('PureCloud.ChatBot.sln'),
      this.destinationPath('PureCloud.ChatBot.sln')
    );
  }

});
