﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace PureCloud.ChatBot.Tests
{
    [TestClass]
    public class UnitTests
    {
        Service.JabberService jabberService = null;

        private Service.ICommandHandler GetCommandHandlers()
        {
            var commandHandler = new TestCommandHandler();
            //commandHandler.Register(new EchoCommandHandler());

            return commandHandler;
        }

        [TestInitialize]
        public void Initialize()
        {
            jabberService = new Service.JabberService("testuser", "testserver", "testpassword", "testnetworkhost", true, GetCommandHandlers());
            jabberService.Start();
        }

        [TestMethod]
        public void BasicTests()
        {
            Assert.IsNotNull(Service.Program.GetJabberService(), "GetJabberService returned null");
            Assert.IsNotNull(Service.Program.GetCommandHandler(), "GetCommandHandler returned null");
        }

        [TestMethod]
        public void GotHelp()
        {
            var help = new Service.CommandHandlers.HelpCommandHandler();
            Assert.IsNotNull(help, "No Help Command Handler found");
            Assert.IsTrue(help.Command.StartsWith("/"), "Invalid command format");
            Assert.IsNotNull(help.HelpText, "No text on how to use help");
            Assert.IsNull(help.Handle(new jabber.protocol.client.Message("", new System.Xml.XmlQualifiedName("test", "test"), new System.Xml.XmlDocument()), "/totallyinvalid"), "Invalid command returned data");
            Assert.IsNotNull(help.Handle(new jabber.protocol.client.Message("", new System.Xml.XmlQualifiedName("test", "test"), new System.Xml.XmlDocument()), "/help"), "Valid command did not return data");
        }

        [TestMethod]
        public void GotEcho()
        {
            var echo = new Service.CommandHandlers.EchoCommandHandler();
            Assert.IsNotNull(echo, "No Echo Command Handler found");
            Assert.IsTrue(echo.Command.StartsWith("/"), "Invalid command format");
            Assert.IsNotNull(echo.HelpText, "No text on how to use help");
            Assert.IsNull(echo.Handle(new jabber.protocol.client.Message("", new System.Xml.XmlQualifiedName("test", "test"), new System.Xml.XmlDocument()), "/totallyinvalid").Output, "Invalid command returned data");
            Assert.IsNull(echo.Handle(new jabber.protocol.client.Message("", new System.Xml.XmlQualifiedName("test", "test"), new System.Xml.XmlDocument()), "/echo").Output, "Valid command with invalid body returned data");
        }

        [TestCleanup]
        public void Cleanup()
        {
            jabberService.Stop();
        }
    }
}
