﻿using jabber.protocol.client;
using PureCloud.ChatBot.Service.Models;
using System.Collections.Generic;
using System.Text;

namespace PureCloud.ChatBot.Service.CommandHandlers
{
    public class HelpCommandHandler : ICommandHandler
	{
		#region Private Members
		private readonly Dictionary<string, ICommandHandler> _commands = new Dictionary<string, ICommandHandler>();
		#endregion Private Members

		#region Public Properties

		public string Command
		{
			get { return "/help"; }
		}

		public string HelpText
		{
			get { return "Returns a list of commands this bot supports."; }
		}
		#endregion Public Properties

		#region Public Methods
		public CommandResult Handle(Message msg, string inputCmd)
		{
			if (inputCmd == Command)
			{
				return GetHelpText();
			}

			return _commands.ContainsKey(inputCmd) 
				? _commands[inputCmd].Handle(msg, inputCmd) 
				: null;
		}

		public void Register(ICommandHandler commandHandler)
		{
			if (_commands.ContainsKey(commandHandler.Command))
			{
				_commands[commandHandler.Command] = commandHandler;
			}
			else
			{
				_commands.Add(commandHandler.Command, commandHandler);
			}
		}
		#endregion Public Methods

		#region Private Methods
		private CommandResult GetHelpText()
		{
			var sb = new StringBuilder();

			foreach (var key in _commands.Keys)
			{
				sb.AppendFormat("**{0}**&nbsp;&nbsp;&nbsp;{1}", key, _commands[key].HelpText);
				sb.AppendLine();
			}

			sb.AppendFormat("**{0}**&nbsp;&nbsp;&nbsp;{1}", Command, HelpText);

			return new CommandResult
				{
					Output = sb.ToString(),
					Tag = Command,
				};
		}
		#endregion Private Methods
	}
}
