﻿using jabber.protocol.client;
using PureCloud.ChatBot.Service.Models;
using System;
using System.Configuration;
using System.Text;
using WolframAlpha.Api.v2;
using WolframAlpha.Api.v2.Requests;

namespace PureCloud.ChatBot.Service.CommandHandlers
{
    public class WolframCommandHandler: ICommandHandler
	{
		#region Private Members
		#endregion Private Members

		#region Public Properties
		public string Command
		{
			get { return "/wolfram"; }
		}

		public string HelpText
		{
			get { return "queries wolfram.  Usage: /wolfram query"; }
		}
		#endregion Public Properties

		#region Constructors
		public WolframCommandHandler()
		{
		}
        #endregion Constructors

        #region Public Methods
        public CommandResult Handle(Message msg, string inputCmd)
        {
            var output = new StringBuilder();
            try
            {
                var queryBuilder = new QueryBuilder();
                queryBuilder.AppId = ConfigurationManager.AppSettings["WolframAppId"];

                string command = msg.Body.Replace(inputCmd, string.Empty).Trim();
                queryBuilder.Input = command;
                var queryRequest = new QueryRequest();
                var result = queryRequest.ExecuteAsync(queryBuilder.QueryUri);
                result.Wait();

                // Format output
                if (result.Result.Error.Equals("true", System.StringComparison.InvariantCultureIgnoreCase))
                {
                    output.AppendFormat("`Error:`{0}. {1}.", result.Result.Error, result.Result.ErrorData.Msg);
                }
                else
                {
                    output.AppendFormat("#### Data Type:\n\r{0}\n\r", result.Result.DataTypes);
                    if (result.Result.Assumptions != null && result.Result.Assumptions.Assumptions != null && result.Result.Assumptions.Assumptions.Length > 0)
                    {
                        output.AppendFormat("#### Assumptions:\n\r");
                        foreach (var assumption in result.Result.Assumptions.Assumptions)
                        {
                            output.AppendFormat("`{0}` ({1})\n\r", assumption.Word, assumption.Type);
                        }
                    }
                    if (result.Result.Pods.Length > 0)
                    {
                        foreach (var pod in result.Result.Pods)
                        {
                            output.AppendFormat("### {0}\n\r", pod.Title);
                            foreach (var subpod in pod.SubPods)
                            {
                                if (subpod.Img != null)
                                {
                                    output.AppendLine("![" + subpod.PlainText + "](" + subpod.Img.Src + ")"); // Only way I could find to have PC display it as an image
                                }
                                else
                                {
                                    output.AppendFormat("`{0}`\n\r", subpod.PlainText);
                                }
                            }
                        }
                    }
                }
            }
            catch (Exception ex)
            {
                output.AppendFormat("`Exception:`{0}.", ex.ToString());
            }

            return new CommandResult
            {
                Output = output.ToString(),
                Tag = Command,
            };
        }
        #endregion Public Methods
    }
}
